@@ -139,7 +139,7 @@ func (c *command) create(cmd *cobra.Command, _ []string) error {
 	}
 
 	if resourceType == resource.KafkaCluster {
-		if err := c.keystore.StoreAPIKey(userKey, clusterId); err != nil {
+		if err := c.keystore.StoreAPIKey(c.V2Client, userKey, clusterId); err != nil {
 			return fmt.Errorf(unableToStoreApiKeyErrorMsg, err)
 		}
 	}
