@@ -16,7 +16,7 @@ import (
 	"github.com/confluentinc/cli/v3/internal/asyncapi"
 	auditlog "github.com/confluentinc/cli/v3/internal/audit-log"
 	"github.com/confluentinc/cli/v3/internal/billing"
-	byok "github.com/confluentinc/cli/v3/internal/byok"
+	"github.com/confluentinc/cli/v3/internal/byok"
 	cloudsignup "github.com/confluentinc/cli/v3/internal/cloud-signup"
 	"github.com/confluentinc/cli/v3/internal/cluster"
 	"github.com/confluentinc/cli/v3/internal/completion"
@@ -104,7 +104,7 @@ func NewConfluentCommand(cfg *config.Config) *cobra.Command {
 	}
 
 	cmd.AddCommand(admin.New(prerunner, cfg.IsTest))
-	cmd.AddCommand(apikey.New(prerunner, nil, flagResolver))
+	cmd.AddCommand(apikey.New(prerunner, flagResolver))
 	cmd.AddCommand(asyncapi.New(prerunner))
 	cmd.AddCommand(auditlog.New(prerunner))
 	cmd.AddCommand(billing.New(prerunner))
@@ -136,7 +136,7 @@ func NewConfluentCommand(cfg *config.Config) *cobra.Command {
 	cmd.AddCommand(update.New(cfg, prerunner, updateClient))
 	cmd.AddCommand(version.New(prerunner, cfg.Version))
 
-	dc := dynamicconfig.New(cfg, nil)
+	dc := dynamicconfig.New(cfg)
 	_ = dc.ParseFlagsIntoConfig(cmd)
 
 	if cfg.IsTest || featureflags.Manager.BoolVariation("cli.flink", dc.Context(), config.CliLaunchDarklyClient, true, false) {
@@ -253,7 +253,7 @@ func getCloudClient(cfg *config.Config, ccloudClientFactory pauth.CCloudClientFa
 }
 
 func deprecateCommandsAndFlags(cmd *cobra.Command, cfg *config.Config) {
-	ctx := dynamicconfig.NewDynamicContext(cfg.Context(), nil)
+	ctx := dynamicconfig.NewDynamicContext(cfg.Context())
 	deprecatedCmds := featureflags.Manager.JsonVariation(featureflags.DeprecationNotices, ctx, config.CliLaunchDarklyClient, true, []any{})
 	cmdToFlagsAndMsg := featureflags.GetAnnouncementsOrDeprecation(deprecatedCmds)
 	for name, flagsAndMsg := range cmdToFlagsAndMsg {
@@ -268,7 +268,7 @@ func deprecateCommandsAndFlags(cmd *cobra.Command, cfg *config.Config) {
 }
 
 func disableCommandAndFlagHelpText(cmd *cobra.Command, cfg *config.Config) {
-	ctx := dynamicconfig.NewDynamicContext(cfg.Context(), nil)
+	ctx := dynamicconfig.NewDynamicContext(cfg.Context())
 	disableResp := featureflags.GetLDDisableMap(ctx)
 	disabledCmdsAndFlags, ok := disableResp["patterns"].([]any)
 	if ok && len(disabledCmdsAndFlags) > 0 {
