@@ -43,5 +43,5 @@ func (c *command) validArgsMultiple(cmd *cobra.Command, args []string) []string
 		return nil
 	}
 
-	return pcmd.AutocompleteEnvironments(c.Client, c.V2Client, c.Context)
+	return pcmd.AutocompleteEnvironments(c.Client, c.V2Client)
 }
