@@ -38,7 +38,7 @@ func (c *command) newRegionListCommand() *cobra.Command {
 	return cmd
 }
 
-func (c *command) regionList(cmd *cobra.Command, args []string) error {
+func (c *command) regionList(cmd *cobra.Command, _ []string) error {
 	cloud, err := cmd.Flags().GetString("cloud")
 	if err != nil {
 		return err
