@@ -23,7 +23,7 @@ func (c *clusterCommand) newConfigurationListCommand() *cobra.Command {
 	return cmd
 }
 
-func (c *clusterCommand) configurationList(cmd *cobra.Command, args []string) error {
+func (c *clusterCommand) configurationList(cmd *cobra.Command, _ []string) error {
 	kafkaREST, err := c.GetKafkaREST()
 	if err != nil {
 		return err
