@@ -13,7 +13,6 @@ import (
 
 	"github.com/confluentinc/cli/v3/pkg/ccstructs"
 	pcmd "github.com/confluentinc/cli/v3/pkg/cmd"
-	"github.com/confluentinc/cli/v3/pkg/config"
 	"github.com/confluentinc/cli/v3/pkg/errors"
 	"github.com/confluentinc/cli/v3/pkg/examples"
 	"github.com/confluentinc/cli/v3/pkg/form"
@@ -39,7 +38,7 @@ Permissions:
 Identity:
   {{.ExternalIdentity}}`))
 
-func (c *clusterCommand) newCreateCommand(cfg *config.Config) *cobra.Command {
+func (c *clusterCommand) newCreateCommand() *cobra.Command {
 	cmd := &cobra.Command{
 		Use:         "create <name>",
 		Short:       "Create a Kafka cluster.",
@@ -68,11 +67,9 @@ func (c *clusterCommand) newCreateCommand(cfg *config.Config) *cobra.Command {
 	pcmd.AddTypeFlag(cmd)
 	cmd.Flags().Int("cku", 0, `Number of Confluent Kafka Units (non-negative). Required for Kafka clusters of type "dedicated".`)
 	cmd.Flags().String("encryption-key", "", "Resource ID of the Cloud Key Management Service key (GCP only).")
+	pcmd.AddByokKeyFlag(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddContextFlag(cmd, c.CLICommand)
-	if cfg.IsCloudLogin() {
-		pcmd.AddByokKeyFlag(cmd, c.AuthenticatedCLICommand)
-		pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
-	}
+	pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddOutputFlag(cmd)
 
 	cobra.CheckErr(cmd.MarkFlagRequired("cloud"))
@@ -120,7 +117,10 @@ func (c *clusterCommand) create(cmd *cobra.Command, args []string) error {
 	var encryptionKey string
 	if cmd.Flags().Changed("encryption-key") {
 		if cloud != "gcp" {
-			return fmt.Errorf("BYOK via `--encryption-key` is only available for GCP. Use `confluent byok create` to register AWS and Azure keys.")
+			return errors.NewErrorWithSuggestions(
+				"BYOK via `--encryption-key` is only available for GCP",
+				"Use `confluent byok create` to register AWS and Azure keys.",
+			)
 		}
 
 		encryptionKey, err = cmd.Flags().GetString("encryption-key")
