@@ -25,8 +25,6 @@ import (
 )
 
 const (
-	clusterId     = "lkc-0000"
-	clusterName   = "testCluster"
 	cloudId       = "aws"
 	regionId      = "us-west-2"
 	environmentId = "abc"
@@ -127,14 +125,14 @@ func (suite *KafkaClusterTestSuite) TestGetLkcForDescribe() {
 	cfg := config.AuthenticatedCloudConfigMock()
 	prerunner := &pcmd.PreRun{Config: cfg}
 	c := &clusterCommand{pcmd.NewAuthenticatedCLICommand(cmd, prerunner)}
-	c.Config = dynamicconfig.New(cfg, nil)
+	c.Context = dynamicconfig.NewDynamicContext(cfg.Context())
 	lkc, err := c.getLkcForDescribe([]string{"lkc-123"})
 	req.Equal("lkc-123", lkc)
 	req.NoError(err)
 	lkc, err = c.getLkcForDescribe([]string{})
-	req.Equal(c.Config.Context().KafkaClusterContext.GetActiveKafkaClusterId(), lkc)
+	req.Equal(c.Context.KafkaClusterContext.GetActiveKafkaClusterId(), lkc)
 	req.NoError(err)
-	c.Config.Context().KafkaClusterContext.GetCurrentKafkaEnvContext().ActiveKafkaCluster = ""
+	c.Context.KafkaClusterContext.GetCurrentKafkaEnvContext().ActiveKafkaCluster = ""
 	lkc, err = c.getLkcForDescribe([]string{})
 	req.Equal("", lkc)
 	req.Equal(errors.NewErrorWithSuggestions(errors.NoKafkaSelectedErrorMsg, errors.NoKafkaForDescribeSuggestions).Error(), err.Error())
