@@ -72,7 +72,6 @@ var Whitelist = []string{
 	"disable_update_check",
 	"disable_updates",
 	"enable_color",
-	"no_browser",
 }
 
 // Config represents the CLI configuration.
@@ -83,7 +82,6 @@ type Config struct {
 	DisableUpdateCheck  bool `json:"disable_update_check"`
 	DisableUpdates      bool `json:"disable_updates,omitempty"`
 	EnableColor         bool `json:"enable_color"`
-	NoBrowser           bool `json:"no_browser"`
 
 	Platforms        map[string]*Platform        `json:"platforms,omitempty"`
 	Credentials      map[string]*Credential      `json:"credentials,omitempty"`
@@ -95,6 +93,7 @@ type Config struct {
 
 	// Deprecated
 	AnonymousId string `json:"anonymous_id,omitempty"`
+	NoBrowser   bool   `json:"no_browser,omitempty"`
 	Ver         string `json:"version,omitempty"`
 
 	// The following configurations are not persisted between runs
