@@ -338,23 +338,6 @@ func (c *Context) SetCurrentFlinkDatabase(id string) error {
 	return nil
 }
 
-func (c *Context) GetCurrentIdentityPool() string {
-	if ctx := c.GetCurrentEnvironmentContext(); ctx != nil {
-		return ctx.CurrentIdentityPool
-	}
-	return ""
-}
-
-func (c *Context) SetCurrentIdentityPool(id string) error {
-	ctx := c.GetCurrentEnvironmentContext()
-	if ctx == nil {
-		return fmt.Errorf("no environment found")
-	}
-
-	ctx.CurrentIdentityPool = id
-	return nil
-}
-
 func (c *Context) GetCurrentServiceAccount() string {
 	if ctx := c.GetCurrentEnvironmentContext(); ctx != nil {
 		return ctx.CurrentServiceAccount
